# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/data_source_rule.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4spaceone/api/cost_analysis/v1/data_source_rule.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"G\n\x17\x44\x61taSourceRuleCondition\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x10\n\x08operator\x18\x03 \x01(\t\"+\n\tMatchRule\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0e\n\x06target\x18\x02 \x01(\t\"\xef\x01\n\x15\x44\x61taSourceRuleActions\x12\x16\n\x0e\x63hange_project\x18\x01 \x01(\t\x12?\n\rmatch_project\x18\x02 \x01(\x0b\x32(.spaceone.api.cost_analysis.v1.MatchRule\x12G\n\x15match_service_account\x18\x03 \x01(\x0b\x32(.spaceone.api.cost_analysis.v1.MatchRule\x12\x34\n\x13\x61\x64\x64_additional_info\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"0\n\x15\x44\x61taSourceRuleOptions\x12\x17\n\x0fstop_processing\x18\x01 \x01(\x08\"\xa3\x03\n\x1b\x43reateDataSourceRuleRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12J\n\nconditions\x18\x02 \x03(\x0b\x32\x36.spaceone.api.cost_analysis.v1.DataSourceRuleCondition\x12J\n\x11\x63onditions_policy\x18\x03 \x01(\x0e\x32/.spaceone.api.cost_analysis.v1.ConditionsPolicy\x12\x45\n\x07\x61\x63tions\x18\x04 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.DataSourceRuleActions\x12\x45\n\x07options\x18\x05 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.DataSourceRuleOptions\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x16\n\x0e\x64\x61ta_source_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\"\xa8\x03\n\x1bUpdateDataSourceRuleRequest\x12\x1b\n\x13\x64\x61ta_source_rule_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12J\n\nconditions\x18\x03 \x03(\x0b\x32\x36.spaceone.api.cost_analysis.v1.DataSourceRuleCondition\x12J\n\x11\x63onditions_policy\x18\x04 \x01(\x0e\x32/.spaceone.api.cost_analysis.v1.ConditionsPolicy\x12\x45\n\x07\x61\x63tions\x18\x05 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.DataSourceRuleActions\x12\x45\n\x07options\x18\x06 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.DataSourceRuleOptions\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"a\n ChangeDataSourceRuleOrderRequest\x12\x1b\n\x13\x64\x61ta_source_rule_id\x18\x01 \x01(\t\x12\r\n\x05order\x18\x02 \x01(\x05\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"G\n\x15\x44\x61taSourceRuleRequest\x12\x1b\n\x13\x64\x61ta_source_rule_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"X\n\x18GetDataSourceRuleRequest\x12\x1b\n\x13\x64\x61ta_source_rule_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x97\x01\n\x13\x44\x61taSourceRuleQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1b\n\x13\x64\x61ta_source_rule_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x16\n\x0e\x64\x61ta_source_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xda\x03\n\x12\x44\x61taSourceRuleInfo\x12\x1b\n\x13\x64\x61ta_source_rule_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05order\x18\x03 \x01(\x05\x12J\n\nconditions\x18\x04 \x03(\x0b\x32\x36.spaceone.api.cost_analysis.v1.DataSourceRuleCondition\x12J\n\x11\x63onditions_policy\x18\x05 \x01(\x0e\x32/.spaceone.api.cost_analysis.v1.ConditionsPolicy\x12\x45\n\x07\x61\x63tions\x18\x06 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.DataSourceRuleActions\x12\x45\n\x07options\x18\x07 \x01(\x0b\x32\x34.spaceone.api.cost_analysis.v1.DataSourceRuleOptions\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x16\n\x0e\x64\x61ta_source_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"n\n\x13\x44\x61taSourceRulesInfo\x12\x42\n\x07results\x18\x01 \x03(\x0b\x32\x31.spaceone.api.cost_analysis.v1.DataSourceRuleInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"b\n\x17\x44\x61taSourceRuleStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t*:\n\x10\x43onditionsPolicy\x12\x08\n\x04NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\x07\n\x03\x41NY\x10\x02\x12\n\n\x06\x41LWAYS\x10\x03\x32\xe9\t\n\x0e\x44\x61taSourceRule\x12\xa4\x01\n\x06\x63reate\x12:.spaceone.api.cost_analysis.v1.CreateDataSourceRuleRequest\x1a\x31.spaceone.api.cost_analysis.v1.DataSourceRuleInfo\"+\x82\xd3\xe4\x93\x02%\"#/cost-analysis/v1/data_source_rules\x12\xb9\x01\n\x06update\x12:.spaceone.api.cost_analysis.v1.UpdateDataSourceRuleRequest\x1a\x31.spaceone.api.cost_analysis.v1.DataSourceRuleInfo\"@\x82\xd3\xe4\x93\x02:\x1a\x38/cost-analysis/v1/data_source_rule/{data_source_rule_id}\x12\xca\x01\n\x0c\x63hange_order\x12?.spaceone.api.cost_analysis.v1.ChangeDataSourceRuleOrderRequest\x1a\x31.spaceone.api.cost_analysis.v1.DataSourceRuleInfo\"F\x82\xd3\xe4\x93\x02@\x1a>/cost-analysis/v1/data_source_rule/{data_source_rule_id}/order\x12\x98\x01\n\x06\x64\x65lete\x12\x34.spaceone.api.cost_analysis.v1.DataSourceRuleRequest\x1a\x16.google.protobuf.Empty\"@\x82\xd3\xe4\x93\x02:*8/cost-analysis/v1/data_source_rule/{data_source_rule_id}\x12\xb3\x01\n\x03get\x12\x37.spaceone.api.cost_analysis.v1.GetDataSourceRuleRequest\x1a\x31.spaceone.api.cost_analysis.v1.DataSourceRuleInfo\"@\x82\xd3\xe4\x93\x02:\x12\x38/cost-analysis/v1/data_source_rule/{data_source_rule_id}\x12\xc9\x01\n\x04list\x12\x32.spaceone.api.cost_analysis.v1.DataSourceRuleQuery\x1a\x32.spaceone.api.cost_analysis.v1.DataSourceRulesInfo\"Y\x82\xd3\xe4\x93\x02S\x12#/cost-analysis/v1/data_source_rulesZ,\"*/cost-analysis/v1/data_source_rules/search\x12\x89\x01\n\x04stat\x12\x36.spaceone.api.cost_analysis.v1.DataSourceRuleStatQuery\x1a\x17.google.protobuf.Struct\"0\x82\xd3\xe4\x93\x02*\"(/cost-analysis/v1/data_source_rules/statb\x06proto3')

_CONDITIONSPOLICY = DESCRIPTOR.enum_types_by_name['ConditionsPolicy']
ConditionsPolicy = enum_type_wrapper.EnumTypeWrapper(_CONDITIONSPOLICY)
NONE = 0
ALL = 1
ANY = 2
ALWAYS = 3


_DATASOURCERULECONDITION = DESCRIPTOR.message_types_by_name['DataSourceRuleCondition']
_MATCHRULE = DESCRIPTOR.message_types_by_name['MatchRule']
_DATASOURCERULEACTIONS = DESCRIPTOR.message_types_by_name['DataSourceRuleActions']
_DATASOURCERULEOPTIONS = DESCRIPTOR.message_types_by_name['DataSourceRuleOptions']
_CREATEDATASOURCERULEREQUEST = DESCRIPTOR.message_types_by_name['CreateDataSourceRuleRequest']
_UPDATEDATASOURCERULEREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataSourceRuleRequest']
_CHANGEDATASOURCERULEORDERREQUEST = DESCRIPTOR.message_types_by_name['ChangeDataSourceRuleOrderRequest']
_DATASOURCERULEREQUEST = DESCRIPTOR.message_types_by_name['DataSourceRuleRequest']
_GETDATASOURCERULEREQUEST = DESCRIPTOR.message_types_by_name['GetDataSourceRuleRequest']
_DATASOURCERULEQUERY = DESCRIPTOR.message_types_by_name['DataSourceRuleQuery']
_DATASOURCERULEINFO = DESCRIPTOR.message_types_by_name['DataSourceRuleInfo']
_DATASOURCERULESINFO = DESCRIPTOR.message_types_by_name['DataSourceRulesInfo']
_DATASOURCERULESTATQUERY = DESCRIPTOR.message_types_by_name['DataSourceRuleStatQuery']
DataSourceRuleCondition = _reflection.GeneratedProtocolMessageType('DataSourceRuleCondition', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULECONDITION,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRuleCondition)
  })
_sym_db.RegisterMessage(DataSourceRuleCondition)

MatchRule = _reflection.GeneratedProtocolMessageType('MatchRule', (_message.Message,), {
  'DESCRIPTOR' : _MATCHRULE,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.MatchRule)
  })
_sym_db.RegisterMessage(MatchRule)

DataSourceRuleActions = _reflection.GeneratedProtocolMessageType('DataSourceRuleActions', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULEACTIONS,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRuleActions)
  })
_sym_db.RegisterMessage(DataSourceRuleActions)

DataSourceRuleOptions = _reflection.GeneratedProtocolMessageType('DataSourceRuleOptions', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULEOPTIONS,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRuleOptions)
  })
_sym_db.RegisterMessage(DataSourceRuleOptions)

CreateDataSourceRuleRequest = _reflection.GeneratedProtocolMessageType('CreateDataSourceRuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEDATASOURCERULEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CreateDataSourceRuleRequest)
  })
_sym_db.RegisterMessage(CreateDataSourceRuleRequest)

UpdateDataSourceRuleRequest = _reflection.GeneratedProtocolMessageType('UpdateDataSourceRuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCERULEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UpdateDataSourceRuleRequest)
  })
_sym_db.RegisterMessage(UpdateDataSourceRuleRequest)

ChangeDataSourceRuleOrderRequest = _reflection.GeneratedProtocolMessageType('ChangeDataSourceRuleOrderRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEDATASOURCERULEORDERREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ChangeDataSourceRuleOrderRequest)
  })
_sym_db.RegisterMessage(ChangeDataSourceRuleOrderRequest)

DataSourceRuleRequest = _reflection.GeneratedProtocolMessageType('DataSourceRuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRuleRequest)
  })
_sym_db.RegisterMessage(DataSourceRuleRequest)

GetDataSourceRuleRequest = _reflection.GeneratedProtocolMessageType('GetDataSourceRuleRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCERULEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetDataSourceRuleRequest)
  })
_sym_db.RegisterMessage(GetDataSourceRuleRequest)

DataSourceRuleQuery = _reflection.GeneratedProtocolMessageType('DataSourceRuleQuery', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULEQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRuleQuery)
  })
_sym_db.RegisterMessage(DataSourceRuleQuery)

DataSourceRuleInfo = _reflection.GeneratedProtocolMessageType('DataSourceRuleInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULEINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRuleInfo)
  })
_sym_db.RegisterMessage(DataSourceRuleInfo)

DataSourceRulesInfo = _reflection.GeneratedProtocolMessageType('DataSourceRulesInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULESINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRulesInfo)
  })
_sym_db.RegisterMessage(DataSourceRulesInfo)

DataSourceRuleStatQuery = _reflection.GeneratedProtocolMessageType('DataSourceRuleStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCERULESTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_rule_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRuleStatQuery)
  })
_sym_db.RegisterMessage(DataSourceRuleStatQuery)

_DATASOURCERULE = DESCRIPTOR.services_by_name['DataSourceRule']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATASOURCERULE.methods_by_name['create']._options = None
  _DATASOURCERULE.methods_by_name['create']._serialized_options = b'\202\323\344\223\002%\"#/cost-analysis/v1/data_source_rules'
  _DATASOURCERULE.methods_by_name['update']._options = None
  _DATASOURCERULE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002:\0328/cost-analysis/v1/data_source_rule/{data_source_rule_id}'
  _DATASOURCERULE.methods_by_name['change_order']._options = None
  _DATASOURCERULE.methods_by_name['change_order']._serialized_options = b'\202\323\344\223\002@\032>/cost-analysis/v1/data_source_rule/{data_source_rule_id}/order'
  _DATASOURCERULE.methods_by_name['delete']._options = None
  _DATASOURCERULE.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002:*8/cost-analysis/v1/data_source_rule/{data_source_rule_id}'
  _DATASOURCERULE.methods_by_name['get']._options = None
  _DATASOURCERULE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002:\0228/cost-analysis/v1/data_source_rule/{data_source_rule_id}'
  _DATASOURCERULE.methods_by_name['list']._options = None
  _DATASOURCERULE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002S\022#/cost-analysis/v1/data_source_rulesZ,\"*/cost-analysis/v1/data_source_rules/search'
  _DATASOURCERULE.methods_by_name['stat']._options = None
  _DATASOURCERULE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002*\"(/cost-analysis/v1/data_source_rules/stat'
  _CONDITIONSPOLICY._serialized_start=2574
  _CONDITIONSPOLICY._serialized_end=2632
  _DATASOURCERULECONDITION._serialized_start=210
  _DATASOURCERULECONDITION._serialized_end=281
  _MATCHRULE._serialized_start=283
  _MATCHRULE._serialized_end=326
  _DATASOURCERULEACTIONS._serialized_start=329
  _DATASOURCERULEACTIONS._serialized_end=568
  _DATASOURCERULEOPTIONS._serialized_start=570
  _DATASOURCERULEOPTIONS._serialized_end=618
  _CREATEDATASOURCERULEREQUEST._serialized_start=621
  _CREATEDATASOURCERULEREQUEST._serialized_end=1040
  _UPDATEDATASOURCERULEREQUEST._serialized_start=1043
  _UPDATEDATASOURCERULEREQUEST._serialized_end=1467
  _CHANGEDATASOURCERULEORDERREQUEST._serialized_start=1469
  _CHANGEDATASOURCERULEORDERREQUEST._serialized_end=1566
  _DATASOURCERULEREQUEST._serialized_start=1568
  _DATASOURCERULEREQUEST._serialized_end=1639
  _GETDATASOURCERULEREQUEST._serialized_start=1641
  _GETDATASOURCERULEREQUEST._serialized_end=1729
  _DATASOURCERULEQUERY._serialized_start=1732
  _DATASOURCERULEQUERY._serialized_end=1883
  _DATASOURCERULEINFO._serialized_start=1886
  _DATASOURCERULEINFO._serialized_end=2360
  _DATASOURCERULESINFO._serialized_start=2362
  _DATASOURCERULESINFO._serialized_end=2472
  _DATASOURCERULESTATQUERY._serialized_start=2474
  _DATASOURCERULESTATQUERY._serialized_end=2572
  _DATASOURCERULE._serialized_start=2635
  _DATASOURCERULE._serialized_end=3892
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.inventory.v1 import collector_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#spaceone/api/inventory/v1/job.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a)spaceone/api/inventory/v1/collector.proto\"/\n\nJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"@\n\rGetJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xb6\x02\n\tJobsQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12>\n\x06status\x18\x03 \x01(\x0e\x32..spaceone.api.inventory.v1.JobsQuery.JobStatus\x12\x14\n\x0c\x63ollector_id\x18\x04 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"p\n\tJobStatus\x12\x12\n\x0eJOB_STATE_NONE\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0c\n\x08\x43\x41NCELED\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\x12\x0b\n\x07SUCCESS\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x12\x0b\n\x07TIMEOUT\x10\x06\"T\n\x08JobsInfo\x12\x33\n\x07results\x18\x01 \x03(\x0b\x32\".spaceone.api.inventory.v1.JobInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"W\n\x0cJobStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xe3\x03\n\x03Job\x12k\n\x06\x64\x65lete\x12%.spaceone.api.inventory.v1.JobRequest\x1a\x16.google.protobuf.Empty\"\"\x82\xd3\xe4\x93\x02\x1c*\x1a/inventory/v1/job/{job_id}\x12w\n\x03get\x12(.spaceone.api.inventory.v1.GetJobRequest\x1a\".spaceone.api.inventory.v1.JobInfo\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/inventory/v1/job/{job_id}\x12\x8a\x01\n\x04list\x12$.spaceone.api.inventory.v1.JobsQuery\x1a#.spaceone.api.inventory.v1.JobsInfo\"7\x82\xd3\xe4\x93\x02\x31\x12\x12/inventory/v1/jobsZ\x1b\"\x19/inventory/v1/jobs/search\x12i\n\x04stat\x12\'.spaceone.api.inventory.v1.JobStatQuery\x1a\x17.google.protobuf.Struct\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/inventory/v1/jobs/statb\x06proto3')



_JOBREQUEST = DESCRIPTOR.message_types_by_name['JobRequest']
_GETJOBREQUEST = DESCRIPTOR.message_types_by_name['GetJobRequest']
_JOBSQUERY = DESCRIPTOR.message_types_by_name['JobsQuery']
_JOBSINFO = DESCRIPTOR.message_types_by_name['JobsInfo']
_JOBSTATQUERY = DESCRIPTOR.message_types_by_name['JobStatQuery']
_JOBSQUERY_JOBSTATUS = _JOBSQUERY.enum_types_by_name['JobStatus']
JobRequest = _reflection.GeneratedProtocolMessageType('JobRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.JobRequest)
  })
_sym_db.RegisterMessage(JobRequest)

GetJobRequest = _reflection.GeneratedProtocolMessageType('GetJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetJobRequest)
  })
_sym_db.RegisterMessage(GetJobRequest)

JobsQuery = _reflection.GeneratedProtocolMessageType('JobsQuery', (_message.Message,), {
  'DESCRIPTOR' : _JOBSQUERY,
  '__module__' : 'spaceone.api.inventory.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.JobsQuery)
  })
_sym_db.RegisterMessage(JobsQuery)

JobsInfo = _reflection.GeneratedProtocolMessageType('JobsInfo', (_message.Message,), {
  'DESCRIPTOR' : _JOBSINFO,
  '__module__' : 'spaceone.api.inventory.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.JobsInfo)
  })
_sym_db.RegisterMessage(JobsInfo)

JobStatQuery = _reflection.GeneratedProtocolMessageType('JobStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _JOBSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.JobStatQuery)
  })
_sym_db.RegisterMessage(JobStatQuery)

_JOB = DESCRIPTOR.services_by_name['Job']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _JOB.methods_by_name['delete']._options = None
  _JOB.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002\034*\032/inventory/v1/job/{job_id}'
  _JOB.methods_by_name['get']._options = None
  _JOB.methods_by_name['get']._serialized_options = b'\202\323\344\223\002\034\022\032/inventory/v1/job/{job_id}'
  _JOB.methods_by_name['list']._options = None
  _JOB.methods_by_name['list']._serialized_options = b'\202\323\344\223\0021\022\022/inventory/v1/jobsZ\033\"\031/inventory/v1/jobs/search'
  _JOB.methods_by_name['stat']._options = None
  _JOB.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\031\"\027/inventory/v1/jobs/stat'
  _JOBREQUEST._serialized_start=232
  _JOBREQUEST._serialized_end=279
  _GETJOBREQUEST._serialized_start=281
  _GETJOBREQUEST._serialized_end=345
  _JOBSQUERY._serialized_start=348
  _JOBSQUERY._serialized_end=658
  _JOBSQUERY_JOBSTATUS._serialized_start=546
  _JOBSQUERY_JOBSTATUS._serialized_end=658
  _JOBSINFO._serialized_start=660
  _JOBSINFO._serialized_end=744
  _JOBSTATQUERY._serialized_start=746
  _JOBSTATQUERY._serialized_end=833
  _JOB._serialized_start=836
  _JOB._serialized_end=1319
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.statistics.v1 import storage_pb2 as spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2


class StorageStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.register = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/register',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.RegisterStorageRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/update',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.UpdateStorageRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
                )
        self.update_plugin = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/update_plugin',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.UpdateStoragePluginRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
                )
        self.verify_plugin = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/verify_plugin',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.enable = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/enable',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
                )
        self.disable = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/disable',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
                )
        self.deregister = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/deregister',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/get',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.GetStorageRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/list',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StoragesInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.statistics.v1.Storage/stat',
                request_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class StorageServicer(object):
    """Missing associated documentation comment in .proto file."""

    def register(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_plugin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def verify_plugin(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disable(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deregister(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_StorageServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'register': grpc.unary_unary_rpc_method_handler(
                    servicer.register,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.RegisterStorageRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.UpdateStorageRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.SerializeToString,
            ),
            'update_plugin': grpc.unary_unary_rpc_method_handler(
                    servicer.update_plugin,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.UpdateStoragePluginRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.SerializeToString,
            ),
            'verify_plugin': grpc.unary_unary_rpc_method_handler(
                    servicer.verify_plugin,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'enable': grpc.unary_unary_rpc_method_handler(
                    servicer.enable,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.SerializeToString,
            ),
            'disable': grpc.unary_unary_rpc_method_handler(
                    servicer.disable,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.SerializeToString,
            ),
            'deregister': grpc.unary_unary_rpc_method_handler(
                    servicer.deregister,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.GetStorageRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StoragesInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.statistics.v1.Storage', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Storage(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def register(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/register',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.RegisterStorageRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/update',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.UpdateStorageRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_plugin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/update_plugin',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.UpdateStoragePluginRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def verify_plugin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/verify_plugin',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/enable',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/disable',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deregister(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/deregister',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/get',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.GetStorageRequest.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/list',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageQuery.SerializeToString,
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StoragesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.statistics.v1.Storage/stat',
            spaceone_dot_api_dot_statistics_dot_v1_dot_storage__pb2.StorageStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/catalog_resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3spaceone/api/provisioning/v1/catalog_resource.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x96\x03\n\x1c\x43reateCatalogResourceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12\x15\n\rresource_name\x18\x04 \x01(\t\x12\x16\n\x0eterraform_code\x18\x05 \x01(\t\x12\x13\n\x0bvalid_value\x18\x06 \x03(\t\x12\x35\n\x14terraform_properties\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12$\n\x03tag\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\t \x01(\t\x12\x12\n\nupdated_at\x18\n \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x0b \x01(\t\x12\x0f\n\x07node_id\x18\x0c \x01(\r\x12\x33\n\x12\x61nsible_properties\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rresource_type\x18\x0e \x01(\t\"\\\n\x16\x43\x61talogResourceRequest\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x01 \x01(\t\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"Y\n\x19GetCatalogResourceRequest\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xb3\x03\n\x1cUpdateCatalogResourceRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x02 \x01(\t\x12\x12\n\ncatalog_id\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12\x13\n\x0bvalid_value\x18\x07 \x03(\t\x12\x35\n\x14terraform_properties\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12$\n\x03tag\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\n \x01(\t\x12\x12\n\nupdated_at\x18\x0b \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x0c \x01(\t\x12\x0f\n\x07node_id\x18\r \x01(\r\x12\x33\n\x12\x61nsible_properties\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rresource_type\x18\x0f \x01(\t\"\xd8\x01\n\x14\x43\x61talogResourceQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x02 \x01(\t\x12\x12\n\ncatalog_id\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12$\n\x03tag\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"c\n\x18\x43\x61talogResourceStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xd2\x03\n\x13\x43\x61talogResourceInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x1b\n\x13\x63\x61talog_resource_id\x18\x02 \x01(\t\x12\x12\n\ncatalog_id\x18\x03 \x01(\t\x12\x13\n\x0bresource_id\x18\x04 \x01(\t\x12\x15\n\rresource_name\x18\x05 \x01(\t\x12\x16\n\x0eterraform_code\x18\x06 \x01(\t\x12\x13\n\x0bvalid_value\x18\x07 \x03(\t\x12\x35\n\x14terraform_properties\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12$\n\x03tag\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\n \x01(\t\x12\x12\n\nupdated_at\x18\x0b \x01(\t\x12\x14\n\x0c\x61nsible_code\x18\x0c \x01(\t\x12\x12\n\ncreated_by\x18\r \x01(\t\x12\x12\n\nupdated_by\x18\x0e \x01(\t\x12\x0f\n\x07node_id\x18\x0f \x01(\r\x12\x33\n\x12\x61nsible_properties\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rresource_type\x18\x11 \x01(\t\"o\n\x14\x43\x61talogResourcesInfo\x12\x42\n\x07results\x18\x01 \x03(\x0b\x32\x31.spaceone.api.provisioning.v1.CatalogResourceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xd3\x08\n\x0f\x43\x61talogResource\x12\xb3\x01\n\x17\x63reate_catalog_resource\x12:.spaceone.api.provisioning.v1.CreateCatalogResourceRequest\x1a\x31.spaceone.api.provisioning.v1.CatalogResourceInfo\")\x82\xd3\xe4\x93\x02#\"!/provisioning/v1/catalog-resource\x12\xd8\x01\n\x15get_catalog_resources\x12\x32.spaceone.api.provisioning.v1.CatalogResourceQuery\x1a\x32.spaceone.api.provisioning.v1.CatalogResourcesInfo\"W\x82\xd3\xe4\x93\x02Q\x12\"/provisioning/v1/catalog-resourcesZ+\")/provisioning/v1/catalog-resources/search\x12\xc3\x01\n\x14get_catalog_resource\x12\x37.spaceone.api.provisioning.v1.GetCatalogResourceRequest\x1a\x31.spaceone.api.provisioning.v1.CatalogResourceInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/provisioning/v1/catalog-resource/{catalog_resource_id}\x12\xb3\x01\n\x17update_catalog_resource\x12:.spaceone.api.provisioning.v1.UpdateCatalogResourceRequest\x1a\x31.spaceone.api.provisioning.v1.CatalogResourceInfo\")\x82\xd3\xe4\x93\x02#\x1a!/provisioning/v1/catalog-resource\x12\xa8\x01\n\x17\x64\x65lete_catalog_resource\x12\x34.spaceone.api.provisioning.v1.CatalogResourceRequest\x1a\x16.google.protobuf.Empty\"?\x82\xd3\xe4\x93\x02\x39*7/provisioning/v1/catalog-resource/{catalog_resource_id}\x12\x87\x01\n\x04stat\x12\x36.spaceone.api.provisioning.v1.CatalogResourceStatQuery\x1a\x17.google.protobuf.Struct\".\x82\xd3\xe4\x93\x02(\"&/provisioning/v1/catalog-resource/statb\x06proto3')



_CREATECATALOGRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['CreateCatalogResourceRequest']
_CATALOGRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['CatalogResourceRequest']
_GETCATALOGRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['GetCatalogResourceRequest']
_UPDATECATALOGRESOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateCatalogResourceRequest']
_CATALOGRESOURCEQUERY = DESCRIPTOR.message_types_by_name['CatalogResourceQuery']
_CATALOGRESOURCESTATQUERY = DESCRIPTOR.message_types_by_name['CatalogResourceStatQuery']
_CATALOGRESOURCEINFO = DESCRIPTOR.message_types_by_name['CatalogResourceInfo']
_CATALOGRESOURCESINFO = DESCRIPTOR.message_types_by_name['CatalogResourcesInfo']
CreateCatalogResourceRequest = _reflection.GeneratedProtocolMessageType('CreateCatalogResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECATALOGRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateCatalogResourceRequest)
  })
_sym_db.RegisterMessage(CreateCatalogResourceRequest)

CatalogResourceRequest = _reflection.GeneratedProtocolMessageType('CatalogResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceRequest)
  })
_sym_db.RegisterMessage(CatalogResourceRequest)

GetCatalogResourceRequest = _reflection.GeneratedProtocolMessageType('GetCatalogResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCATALOGRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.GetCatalogResourceRequest)
  })
_sym_db.RegisterMessage(GetCatalogResourceRequest)

UpdateCatalogResourceRequest = _reflection.GeneratedProtocolMessageType('UpdateCatalogResourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECATALOGRESOURCEREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateCatalogResourceRequest)
  })
_sym_db.RegisterMessage(UpdateCatalogResourceRequest)

CatalogResourceQuery = _reflection.GeneratedProtocolMessageType('CatalogResourceQuery', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCEQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceQuery)
  })
_sym_db.RegisterMessage(CatalogResourceQuery)

CatalogResourceStatQuery = _reflection.GeneratedProtocolMessageType('CatalogResourceStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCESTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceStatQuery)
  })
_sym_db.RegisterMessage(CatalogResourceStatQuery)

CatalogResourceInfo = _reflection.GeneratedProtocolMessageType('CatalogResourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCEINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourceInfo)
  })
_sym_db.RegisterMessage(CatalogResourceInfo)

CatalogResourcesInfo = _reflection.GeneratedProtocolMessageType('CatalogResourcesInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGRESOURCESINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogResourcesInfo)
  })
_sym_db.RegisterMessage(CatalogResourcesInfo)

_CATALOGRESOURCE = DESCRIPTOR.services_by_name['CatalogResource']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CATALOGRESOURCE.methods_by_name['create_catalog_resource']._options = None
  _CATALOGRESOURCE.methods_by_name['create_catalog_resource']._serialized_options = b'\202\323\344\223\002#\"!/provisioning/v1/catalog-resource'
  _CATALOGRESOURCE.methods_by_name['get_catalog_resources']._options = None
  _CATALOGRESOURCE.methods_by_name['get_catalog_resources']._serialized_options = b'\202\323\344\223\002Q\022\"/provisioning/v1/catalog-resourcesZ+\")/provisioning/v1/catalog-resources/search'
  _CATALOGRESOURCE.methods_by_name['get_catalog_resource']._options = None
  _CATALOGRESOURCE.methods_by_name['get_catalog_resource']._serialized_options = b'\202\323\344\223\0029\0227/provisioning/v1/catalog-resource/{catalog_resource_id}'
  _CATALOGRESOURCE.methods_by_name['update_catalog_resource']._options = None
  _CATALOGRESOURCE.methods_by_name['update_catalog_resource']._serialized_options = b'\202\323\344\223\002#\032!/provisioning/v1/catalog-resource'
  _CATALOGRESOURCE.methods_by_name['delete_catalog_resource']._options = None
  _CATALOGRESOURCE.methods_by_name['delete_catalog_resource']._serialized_options = b'\202\323\344\223\0029*7/provisioning/v1/catalog-resource/{catalog_resource_id}'
  _CATALOGRESOURCE.methods_by_name['stat']._options = None
  _CATALOGRESOURCE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002(\"&/provisioning/v1/catalog-resource/stat'
  _CREATECATALOGRESOURCEREQUEST._serialized_start=209
  _CREATECATALOGRESOURCEREQUEST._serialized_end=615
  _CATALOGRESOURCEREQUEST._serialized_start=617
  _CATALOGRESOURCEREQUEST._serialized_end=709
  _GETCATALOGRESOURCEREQUEST._serialized_start=711
  _GETCATALOGRESOURCEREQUEST._serialized_end=800
  _UPDATECATALOGRESOURCEREQUEST._serialized_start=803
  _UPDATECATALOGRESOURCEREQUEST._serialized_end=1238
  _CATALOGRESOURCEQUERY._serialized_start=1241
  _CATALOGRESOURCEQUERY._serialized_end=1457
  _CATALOGRESOURCESTATQUERY._serialized_start=1459
  _CATALOGRESOURCESTATQUERY._serialized_end=1558
  _CATALOGRESOURCEINFO._serialized_start=1561
  _CATALOGRESOURCEINFO._serialized_end=2027
  _CATALOGRESOURCESINFO._serialized_start=2029
  _CATALOGRESOURCESINFO._serialized_end=2140
  _CATALOGRESOURCE._serialized_start=2143
  _CATALOGRESOURCE._serialized_end=3250
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.cost_analysis.v1 import budget_usage_pb2 as spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__usage__pb2


class BudgetUsageStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.list = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.BudgetUsage/list',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__usage__pb2.BudgetUsageQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__usage__pb2.BudgetUsagesInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.BudgetUsage/stat',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__usage__pb2.BudgetUsageStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class BudgetUsageServicer(object):
    """Missing associated documentation comment in .proto file."""

    def list(self, request, context):
        """
        desc: Gets a list of all BudgetUsages. You can use a query to get a filtered list of BudgetUsages.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "budget_id": "budget-abb377eb9e8b",
        "name": "Cloudforet-Budget3",
        "date": "2022-01",
        "usd_cost": 7671.164,
        "limit": 10000.0,
        "domain_id": "domain-58010aa2e451",
        "updated_at": "2022-07-19T04:26:08.099Z"
        },
        {
        "budget_id": "budget-abb377eb9e8b",
        "name": "Cloudforet-Budget3",
        "date": "2022-02",
        "usd_cost": 5931.771,
        "limit": 11000.0,
        "domain_id": "domain-58010aa2e451",
        "updated_at": "2022-07-19T04:26:08.105Z"
        }
        ],
        "total_count": 12
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BudgetUsageServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__usage__pb2.BudgetUsageQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__usage__pb2.BudgetUsagesInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__usage__pb2.BudgetUsageStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.cost_analysis.v1.BudgetUsage', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class BudgetUsage(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.BudgetUsage/list',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__usage__pb2.BudgetUsageQuery.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__usage__pb2.BudgetUsagesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.BudgetUsage/stat',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_budget__usage__pb2.BudgetUsageStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/job_task.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.inventory.v1 import collector_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(spaceone/api/inventory/v1/job_task.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a)spaceone/api/inventory/v1/collector.proto\"8\n\x0eJobTaskRequest\x12\x13\n\x0bjob_task_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"I\n\x11GetJobTaskRequest\x12\x13\n\x0bjob_task_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xfe\x02\n\x0cJobTaskQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x13\n\x0bjob_task_id\x18\x02 \x01(\t\x12\x45\n\x06status\x18\x03 \x01(\x0e\x32\x35.spaceone.api.inventory.v1.JobTaskQuery.JobTaskStatus\x12\x0e\n\x06job_id\x18\x04 \x01(\t\x12\x11\n\tsecret_id\x18\x05 \x01(\t\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12\x12\n\nproject_id\x18\x08 \x01(\t\x12\x11\n\tdomain_id\x18\t \x01(\t\"n\n\rJobTaskStatus\x12\x17\n\x13JOB_TASK_STATE_NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0c\n\x08\x43\x41NCELED\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\x12\x0b\n\x07SUCCESS\x10\x04\x12\x0b\n\x07\x46\x41ILURE\x10\x05\"\xbb\x04\n\x0bJobTaskInfo\x12\x13\n\x0bjob_task_id\x18\x01 \x01(\t\x12\x44\n\x06status\x18\x02 \x01(\x0e\x32\x34.spaceone.api.inventory.v1.JobTaskInfo.JobTaskStatus\x12\x15\n\rcreated_count\x18\x03 \x01(\x05\x12\x15\n\rupdated_count\x18\x04 \x01(\x05\x12\x15\n\rfailure_count\x18\x05 \x01(\x05\x12\x15\n\rdeleted_count\x18\x06 \x01(\x05\x12\x1a\n\x12\x64isconnected_count\x18\x07 \x01(\x05\x12\x34\n\x06\x65rrors\x18\t \x03(\x0b\x32$.spaceone.api.inventory.v1.ErrorInfo\x12\x0e\n\x06job_id\x18\x0b \x01(\t\x12\x11\n\tsecret_id\x18\x0c \x01(\t\x12\x10\n\x08provider\x18\r \x01(\t\x12\x1a\n\x12service_account_id\x18\x0e \x01(\t\x12\x12\n\nproject_id\x18\x0f \x01(\t\x12\x11\n\tdomain_id\x18\x10 \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x12\n\nstarted_at\x18\x16 \x01(\t\x12\x13\n\x0b\x66inished_at\x18\x17 \x01(\t\"n\n\rJobTaskStatus\x12\x17\n\x13JOB_TASK_STATE_NONE\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\x0c\n\x08\x43\x41NCELED\x10\x02\x12\x0f\n\x0bIN_PROGRESS\x10\x03\x12\x0b\n\x07SUCCESS\x10\x04\x12\x0b\n\x07\x46\x41ILURE\x10\x05\"\\\n\x0cJobTasksInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.inventory.v1.JobTaskInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"[\n\x10JobTaskStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa2\x04\n\x07JobTask\x12y\n\x06\x64\x65lete\x12).spaceone.api.inventory.v1.JobTaskRequest\x1a\x16.google.protobuf.Empty\",\x82\xd3\xe4\x93\x02&*$/inventory/v1/job-task/{job_task_id}\x12\x89\x01\n\x03get\x12,.spaceone.api.inventory.v1.GetJobTaskRequest\x1a&.spaceone.api.inventory.v1.JobTaskInfo\",\x82\xd3\xe4\x93\x02&\x12$/inventory/v1/job-task/{job_task_id}\x12\x9b\x01\n\x04list\x12\'.spaceone.api.inventory.v1.JobTaskQuery\x1a\'.spaceone.api.inventory.v1.JobTasksInfo\"A\x82\xd3\xe4\x93\x02;\x12\x17/inventory/v1/job-tasksZ \"\x1e/inventory/v1/job-tasks/search\x12r\n\x04stat\x12+.spaceone.api.inventory.v1.JobTaskStatQuery\x1a\x17.google.protobuf.Struct\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/inventory/v1/job-tasks/statb\x06proto3')



_JOBTASKREQUEST = DESCRIPTOR.message_types_by_name['JobTaskRequest']
_GETJOBTASKREQUEST = DESCRIPTOR.message_types_by_name['GetJobTaskRequest']
_JOBTASKQUERY = DESCRIPTOR.message_types_by_name['JobTaskQuery']
_JOBTASKINFO = DESCRIPTOR.message_types_by_name['JobTaskInfo']
_JOBTASKSINFO = DESCRIPTOR.message_types_by_name['JobTasksInfo']
_JOBTASKSTATQUERY = DESCRIPTOR.message_types_by_name['JobTaskStatQuery']
_JOBTASKQUERY_JOBTASKSTATUS = _JOBTASKQUERY.enum_types_by_name['JobTaskStatus']
_JOBTASKINFO_JOBTASKSTATUS = _JOBTASKINFO.enum_types_by_name['JobTaskStatus']
JobTaskRequest = _reflection.GeneratedProtocolMessageType('JobTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBTASKREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.job_task_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.JobTaskRequest)
  })
_sym_db.RegisterMessage(JobTaskRequest)

GetJobTaskRequest = _reflection.GeneratedProtocolMessageType('GetJobTaskRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBTASKREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.job_task_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetJobTaskRequest)
  })
_sym_db.RegisterMessage(GetJobTaskRequest)

JobTaskQuery = _reflection.GeneratedProtocolMessageType('JobTaskQuery', (_message.Message,), {
  'DESCRIPTOR' : _JOBTASKQUERY,
  '__module__' : 'spaceone.api.inventory.v1.job_task_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.JobTaskQuery)
  })
_sym_db.RegisterMessage(JobTaskQuery)

JobTaskInfo = _reflection.GeneratedProtocolMessageType('JobTaskInfo', (_message.Message,), {
  'DESCRIPTOR' : _JOBTASKINFO,
  '__module__' : 'spaceone.api.inventory.v1.job_task_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.JobTaskInfo)
  })
_sym_db.RegisterMessage(JobTaskInfo)

JobTasksInfo = _reflection.GeneratedProtocolMessageType('JobTasksInfo', (_message.Message,), {
  'DESCRIPTOR' : _JOBTASKSINFO,
  '__module__' : 'spaceone.api.inventory.v1.job_task_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.JobTasksInfo)
  })
_sym_db.RegisterMessage(JobTasksInfo)

JobTaskStatQuery = _reflection.GeneratedProtocolMessageType('JobTaskStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _JOBTASKSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.job_task_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.JobTaskStatQuery)
  })
_sym_db.RegisterMessage(JobTaskStatQuery)

_JOBTASK = DESCRIPTOR.services_by_name['JobTask']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _JOBTASK.methods_by_name['delete']._options = None
  _JOBTASK.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002&*$/inventory/v1/job-task/{job_task_id}'
  _JOBTASK.methods_by_name['get']._options = None
  _JOBTASK.methods_by_name['get']._serialized_options = b'\202\323\344\223\002&\022$/inventory/v1/job-task/{job_task_id}'
  _JOBTASK.methods_by_name['list']._options = None
  _JOBTASK.methods_by_name['list']._serialized_options = b'\202\323\344\223\002;\022\027/inventory/v1/job-tasksZ \"\036/inventory/v1/job-tasks/search'
  _JOBTASK.methods_by_name['stat']._options = None
  _JOBTASK.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\036\"\034/inventory/v1/job-tasks/stat'
  _JOBTASKREQUEST._serialized_start=237
  _JOBTASKREQUEST._serialized_end=293
  _GETJOBTASKREQUEST._serialized_start=295
  _GETJOBTASKREQUEST._serialized_end=368
  _JOBTASKQUERY._serialized_start=371
  _JOBTASKQUERY._serialized_end=753
  _JOBTASKQUERY_JOBTASKSTATUS._serialized_start=643
  _JOBTASKQUERY_JOBTASKSTATUS._serialized_end=753
  _JOBTASKINFO._serialized_start=756
  _JOBTASKINFO._serialized_end=1327
  _JOBTASKINFO_JOBTASKSTATUS._serialized_start=643
  _JOBTASKINFO_JOBTASKSTATUS._serialized_end=753
  _JOBTASKSINFO._serialized_start=1329
  _JOBTASKSINFO._serialized_end=1421
  _JOBTASKSTATQUERY._serialized_start=1423
  _JOBTASKSTATQUERY._serialized_end=1514
  _JOBTASK._serialized_start=1517
  _JOBTASK._serialized_end=2063
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/plugin/log.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(spaceone/api/monitoring/plugin/log.proto\x12\x1espaceone.api.monitoring.plugin\x1a\x1cgoogle/protobuf/struct.proto\"!\n\x04Sort\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\x08\"\x8c\x02\n\nLogRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12&\n\x05query\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07keyword\x18\x05 \x01(\t\x12\r\n\x05start\x18\n \x01(\t\x12\x0b\n\x03\x65nd\x18\x0b \x01(\t\x12\x32\n\x04sort\x18\x0c \x01(\x0b\x32$.spaceone.api.monitoring.plugin.Sort\x12\r\n\x05limit\x18\r \x01(\x05\"8\n\x0cLogsDataInfo\x12(\n\x07results\x18\x01 \x03(\x0b\x32\x17.google.protobuf.Struct2k\n\x03Log\x12\x64\n\x04list\x12*.spaceone.api.monitoring.plugin.LogRequest\x1a,.spaceone.api.monitoring.plugin.LogsDataInfo\"\x00\x30\x01\x62\x06proto3')



_SORT = DESCRIPTOR.message_types_by_name['Sort']
_LOGREQUEST = DESCRIPTOR.message_types_by_name['LogRequest']
_LOGSDATAINFO = DESCRIPTOR.message_types_by_name['LogsDataInfo']
Sort = _reflection.GeneratedProtocolMessageType('Sort', (_message.Message,), {
  'DESCRIPTOR' : _SORT,
  '__module__' : 'spaceone.api.monitoring.plugin.log_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.Sort)
  })
_sym_db.RegisterMessage(Sort)

LogRequest = _reflection.GeneratedProtocolMessageType('LogRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOGREQUEST,
  '__module__' : 'spaceone.api.monitoring.plugin.log_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.LogRequest)
  })
_sym_db.RegisterMessage(LogRequest)

LogsDataInfo = _reflection.GeneratedProtocolMessageType('LogsDataInfo', (_message.Message,), {
  'DESCRIPTOR' : _LOGSDATAINFO,
  '__module__' : 'spaceone.api.monitoring.plugin.log_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.LogsDataInfo)
  })
_sym_db.RegisterMessage(LogsDataInfo)

_LOG = DESCRIPTOR.services_by_name['Log']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SORT._serialized_start=106
  _SORT._serialized_end=139
  _LOGREQUEST._serialized_start=142
  _LOGREQUEST._serialized_end=410
  _LOGSDATAINFO._serialized_start=412
  _LOGSDATAINFO._serialized_end=468
  _LOG._serialized_start=470
  _LOG._serialized_end=577
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.notification.v1 import notification_pb2 as spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2


class NotificationStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.notification.v1.Notification/create',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.CreateNotificationRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.push = channel.unary_unary(
                '/spaceone.api.notification.v1.Notification/push',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.PushNotificationRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.notification.v1.Notification/delete',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.NotificationRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.set_read = channel.unary_unary(
                '/spaceone.api.notification.v1.Notification/set_read',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.SetReadNotificationRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.notification.v1.Notification/get',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.GetNotificationRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.NotificationInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.notification.v1.Notification/list',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.NotificationQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.NotificationsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.notification.v1.Notification/stat',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.NotificationStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class NotificationServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new Notification. When a Notification is created, it is delivered to a UserChannel or a ProjectChannel depending on the parameter `resource_type`. If a Notification is delivered to a UserChannel, the `resource_type` is `identity.User`, and if a Notification is delivered to a ProjectChannel, the `resource_type` is `identity.Project`.
        request_example: >-
        {
        "resource_type": "identity.Project",
        "resource_id": "resource-123456789012",
        "topic": "monitoring.Alert",
        "message": {
        "title": "[Alerting] Not Running Pods 0:OK alert",
        "description": "[spaceone-dev] Not Running Pods 0 is OK\n\nFailure level : WorkerNode\nPanel ... ",
        "tags": {
        "urgency": "LOW",
        "resource_id": "pod",
        "assignee": "user1@email.com",
        "created_at": "2022-01-01T17:12:45.990Z",
        "state": "ACKNOWLEDGED",
        "project_id": "project-123456789012"
        }
        },
        "notification_type": "INFO",
        "notification_level": "LV2"
        }
        response_example: >-
        {
        "notification_id": "notification-123456789012",
        "topic": "monitoring.Alert",
        "message": {
        "title": "[Alerting] Not Running Pods 0:OK alert",
        "description": "[spaceone-dev] Not Running Pods 0 is OK\n\nFailure level : WorkerNode\nPanel ... ",
        "tags": {
        "urgency": "LOW",
        "resource_id": "pod",
        "assignee": "user1@email.com",
        "created_at": "2022-01-01T17:12:45.990Z",
        "state": "ACKNOWLEDGED",
        "project_id": "project-123456789012"
        }
        },
        "notification_type": "INFO",
        "notification_level": "LV2",
        "is_read": true,
        "user_id": "Cloudforet@mz.co.kr",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T17:12:40.990Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def push(self, request, context):
        """
        desc: Manually raises a Notification. A Notification is raised with a message to be sent using a valid specific Protocol, and data used for a specific Protocol such as a phone number.
        request_example: >-
        {
        "protocol_id": "protocol-fb30cb6c28d6",
        "data": {
        "phone_number": "01012345678"
        },
        "message": {
        "tags": [
        {
        "key": "project_id",
        "value": "project-xxxx"
        },
        {
        "key": "project_name",
        "value": "Test Project"
        },
        {
        "key": "resource_id",
        "value": "server-yyyyy"
        },
        {
        "key": "resource_name",
        "value": "web-server-001"
        }
        ],
        "description": "This is Sample Message",
        "title": "Sample"
        }
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes multiple Notifications. You must specify `notifications` of the list of Notifications to delete.
        request_example: >-
        {
        "notifications": [
        "notification-4025c1b61225",
        "notification-13hk3fh32534",
        "notification-4kth40jth5jy"
        ]
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def set_read(self, request, context):
        """
        desc: Marks a Notification as read. When a Notification is raised and if the Notification has been acknowledged, it can be marked as read with the method.
        request_example: >-
        {
        "notifications": [
        "notification-6c548a37ee77",
        "notification-4j3jt9384fnf"
        ]
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Notification. Prints detailed information about the Notification, including not only the message contents(`title`, `description`) but also related data such as created time and urgency.
        request_example: >-
        {
        "notification_id": "notification-4025c1b61225"
        }
        response_example: >-
        {
        "notification_id": "notification-4025c1b61225",
        "topic": "monitoring.Alert",
        "message": {
        "tags": {
        "project_id": "project-18655561c535",
        "created_at": null,
        "urgency": "LOW",
        "state": "TRIGGERED",
        "resource_id": "AWS/NetworkELB",
        "resource_name": "[Asia Pacific (Seoul)]:[AWS/NetworkELB]: net/af83f347171a044af46453ebb34c8225/743a23562a96c595"
        },
        "title": "[Asia Pacific (Seoul)]: NLB-TCP_Target_Reset_Count-Alert",
        "description": "Threshold Crossed: 1 out of the last 1 datapoints [200.0 (25/06/21 06:38:00)] was not greater than the threshold (200.0)"
        },
        "notification_type": "INFO",
        "notification_level": "ALL",
        "is_read": true,
        "user_id": "user1@spaceone.dev",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2021-06-25T06:42:05.867Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Notifications. You can use a query to get a filtered list of Notifications.
        request_example: >-
        {
        "query": {
        "filter": [
        {
        "key": "notification_type",
        "value": "INFO",
        "operator": "eq"
        }
        ]
        }
        }
        response_example: >-
        {
        "results": [
        {
        "notification_id": "notification-9f1476af11b7",
        "topic": "monitoring.Alert",
        "message": {
        "tags": {
        "state": "ACKNOWLEDGED",
        "resource_id": "pod",
        "project_id": "project-18655561c535",
        "urgency": "LOW",
        "created_at": null,
        "assignee": "yuda@test.co"
        },
        "title": "[Alerting] Not Running Pods 0:OK alert",
        "description": "[cloudone-dev-v1-eks-cluster] Not Running Pods 0 is OK"
        },
        "notification_type": "INFO",
        "notification_level": "LV2",
        "is_read": true,
        "user_id": "user33@spaceone.dev",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2021-06-21T17:13:39.570Z"
        },
        {
        "notification_id": "notification-4025c1b61225",
        "topic": "monitoring.Alert",
        "message": {
        "title": "[Asia Pacific (Seoul)]: NLB-TCP_Target_Reset_Count-Alert",
        "description": "Threshold Crossed: 1 out of the last 1 datapoints [200.0 (25/06/21 06:38:00)] was not greater than the threshold (200.0)",
        "tags": {
        "resource_id": "AWS/NetworkELB",
        "resource_name": "[Asia Pacific (Seoul)]:[AWS/NetworkELB]: net/dfsbvs/advdr32rwqdsvzc",
        "created_at": null,
        "state": "TRIGGERED",
        "project_id": "project-18655561c535",
        "urgency": "LOW"
        }
        },
        "notification_type": "INFO",
        "notification_level": "ALL",
        "is_read": true,
        "user_id": "user1@cloudforet.io",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2021-06-25T06:42:05.867Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NotificationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.CreateNotificationRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'push': grpc.unary_unary_rpc_method_handler(
                    servicer.push,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.PushNotificationRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.NotificationRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'set_read': grpc.unary_unary_rpc_method_handler(
                    servicer.set_read,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.SetReadNotificationRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.GetNotificationRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.NotificationInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.NotificationQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.NotificationsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.NotificationStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.notification.v1.Notification', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Notification(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Notification/create',
            spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.CreateNotificationRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def push(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Notification/push',
            spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.PushNotificationRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Notification/delete',
            spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.NotificationRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def set_read(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Notification/set_read',
            spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.SetReadNotificationRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Notification/get',
            spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.GetNotificationRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.NotificationInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Notification/list',
            spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.NotificationQuery.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.NotificationsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Notification/stat',
            spaceone_dot_api_dot_notification_dot_v1_dot_notification__pb2.NotificationStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/authorization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import handler_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_handler__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,spaceone/api/identity/v1/authorization.proto\x12\x18spaceone.api.identity.v1\x1a\x1cgoogle/api/annotations.proto\x1a\"spaceone/api/core/v1/handler.proto2\x9e\x01\n\rAuthorization\x12\x8c\x01\n\x06verify\x12*.spaceone.api.core.v1.AuthorizationRequest\x1a+.spaceone.api.core.v1.AuthorizationResponse\")\x82\xd3\xe4\x93\x02#\"!/identity/v1/authorization/verifyb\x06proto3')



_AUTHORIZATION = DESCRIPTOR.services_by_name['Authorization']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _AUTHORIZATION.methods_by_name['verify']._options = None
  _AUTHORIZATION.methods_by_name['verify']._serialized_options = b'\202\323\344\223\002#\"!/identity/v1/authorization/verify'
  _AUTHORIZATION._serialized_start=141
  _AUTHORIZATION._serialized_end=299
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/service_account.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.identity.v1 import project_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_project__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.spaceone/api/identity/v1/service_account.proto\x12\x18spaceone.api.identity.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a&spaceone/api/identity/v1/project.proto\"\xf4\x01\n\x1b\x43reateServiceAccountRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1c\n\x14service_account_type\x18\x0b \x01(\t\x12\"\n\x1atrusted_service_account_id\x18\x0c \x01(\t\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"\x89\x02\n\x1bUpdateServiceAccountRequest\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\"\n\x1atrusted_service_account_id\x18\x06 \x01(\t\x12\'\n\x1frelease_trusted_service_account\x18\x07 \x01(\x08\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"F\n\x15ServiceAccountRequest\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"W\n\x18GetServiceAccountRequest\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xf5\x01\n\x13ServiceAccountQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1a\n\x12service_account_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1c\n\x14service_account_type\x18\x04 \x01(\t\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\"\n\x1atrusted_service_account_id\x18\x06 \x01(\t\x12\x12\n\nproject_id\x18\x07 \x01(\t\x12\r\n\x05scope\x18\x08 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xd3\x02\n\x12ServiceAccountInfo\x12\x1a\n\x12service_account_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1c\n\x14service_account_type\x18\x03 \x01(\t\x12%\n\x04\x64\x61ta\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x10\n\x08provider\x18\x05 \x01(\t\x12\"\n\x1atrusted_service_account_id\x18\x06 \x01(\t\x12;\n\x0cproject_info\x18\x07 \x01(\x0b\x32%.spaceone.api.identity.v1.ProjectInfo\x12\r\n\x05scope\x18\x08 \x01(\t\x12\x11\n\tdomain_id\x18\x15 \x01(\t\x12%\n\x04tags\x18\x16 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\x17 \x01(\t\"i\n\x13ServiceAccountsInfo\x12=\n\x07results\x18\x01 \x03(\x0b\x32,.spaceone.api.identity.v1.ServiceAccountInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"b\n\x17ServiceAccountStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\x94\x01\n\x11RegionConfigQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x1a\n\x12service_account_id\x18\x05 \x01(\t\"\xa3\x01\n\x10RegionConfigData\x12\x13\n\x0bregion_name\x18\x01 \x01(\t\x12L\n\x0cis_available\x18\x02 \x01(\x0e\x32\x36.spaceone.api.identity.v1.RegionConfigData.IsAvailable\",\n\x0bIsAvailable\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05\x46\x41LSE\x10\x01\x12\x08\n\x04TRUE\x10\x02\"e\n\x11RegionsConfigInfo\x12;\n\x07results\x18\x01 \x03(\x0b\x32*.spaceone.api.identity.v1.RegionConfigInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\xbe\x01\n\x10RegionConfigInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x41\n\rregion_config\x18\x05 \x03(\x0b\x32*.spaceone.api.identity.v1.RegionConfigData\x12\x12\n\ncreated_at\x18\x06 \x01(\t\"\xb3\x01\n\x19UpdateRegionConfigRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x41\n\rregion_config\x18\x05 \x03(\x0b\x32*.spaceone.api.identity.v1.RegionConfigData\"m\n\x16GetRegionConfigRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t2\x8e\x0c\n\x0eServiceAccount\x12\x94\x01\n\x06\x63reate\x12\x35.spaceone.api.identity.v1.CreateServiceAccountRequest\x1a,.spaceone.api.identity.v1.ServiceAccountInfo\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/identity/v1/service-accounts\x12\xa8\x01\n\x06update\x12\x35.spaceone.api.identity.v1.UpdateServiceAccountRequest\x1a,.spaceone.api.identity.v1.ServiceAccountInfo\"9\x82\xd3\xe4\x93\x02\x33\x1a\x31/identity/v1/service-account/{service_account_id}\x12\xb3\x01\n\x14update_region_config\x12\x33.spaceone.api.identity.v1.UpdateRegionConfigRequest\x1a+.spaceone.api.identity.v1.RegionsConfigInfo\"9\x82\xd3\xe4\x93\x02\x33\x1a\x31/identity/v1/service-account/update-region-config\x12\x8c\x01\n\x06\x64\x65lete\x12/.spaceone.api.identity.v1.ServiceAccountRequest\x1a\x16.google.protobuf.Empty\"9\x82\xd3\xe4\x93\x02\x33*1/identity/v1/service-account/{service_account_id}\x12\xaa\x01\n\x11get_region_config\x12\x30.spaceone.api.identity.v1.GetRegionConfigRequest\x1a+.spaceone.api.identity.v1.RegionsConfigInfo\"6\x82\xd3\xe4\x93\x02\x30\x1a./identity/v1/service-account/get-region-config\x12\xa2\x01\n\x03get\x12\x32.spaceone.api.identity.v1.GetServiceAccountRequest\x1a,.spaceone.api.identity.v1.ServiceAccountInfo\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/identity/v1/service-account/{service_account_id}\x12\xb3\x01\n\x04list\x12-.spaceone.api.identity.v1.ServiceAccountQuery\x1a-.spaceone.api.identity.v1.ServiceAccountsInfo\"M\x82\xd3\xe4\x93\x02G\x12\x1d/identity/v1/service-accountsZ&\"$/identity/v1/service-accounts/search\x12\xec\x01\n\x15list_available_region\x12+.spaceone.api.identity.v1.RegionConfigQuery\x1a+.spaceone.api.identity.v1.RegionsConfigInfo\"y\x82\xd3\xe4\x93\x02s\x12\x33/identity/v1/service-accounts/list-available-regionZ<\":/identity/v1/service-accounts/list-available-region/search\x12~\n\x04stat\x12\x31.spaceone.api.identity.v1.ServiceAccountStatQuery\x1a\x17.google.protobuf.Struct\"*\x82\xd3\xe4\x93\x02$\"\"/identity/v1/service-accounts/statb\x06proto3')



_CREATESERVICEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['CreateServiceAccountRequest']
_UPDATESERVICEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['UpdateServiceAccountRequest']
_SERVICEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['ServiceAccountRequest']
_GETSERVICEACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['GetServiceAccountRequest']
_SERVICEACCOUNTQUERY = DESCRIPTOR.message_types_by_name['ServiceAccountQuery']
_SERVICEACCOUNTINFO = DESCRIPTOR.message_types_by_name['ServiceAccountInfo']
_SERVICEACCOUNTSINFO = DESCRIPTOR.message_types_by_name['ServiceAccountsInfo']
_SERVICEACCOUNTSTATQUERY = DESCRIPTOR.message_types_by_name['ServiceAccountStatQuery']
_REGIONCONFIGQUERY = DESCRIPTOR.message_types_by_name['RegionConfigQuery']
_REGIONCONFIGDATA = DESCRIPTOR.message_types_by_name['RegionConfigData']
_REGIONSCONFIGINFO = DESCRIPTOR.message_types_by_name['RegionsConfigInfo']
_REGIONCONFIGINFO = DESCRIPTOR.message_types_by_name['RegionConfigInfo']
_UPDATEREGIONCONFIGREQUEST = DESCRIPTOR.message_types_by_name['UpdateRegionConfigRequest']
_GETREGIONCONFIGREQUEST = DESCRIPTOR.message_types_by_name['GetRegionConfigRequest']
_REGIONCONFIGDATA_ISAVAILABLE = _REGIONCONFIGDATA.enum_types_by_name['IsAvailable']
CreateServiceAccountRequest = _reflection.GeneratedProtocolMessageType('CreateServiceAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESERVICEACCOUNTREQUEST,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.CreateServiceAccountRequest)
  })
_sym_db.RegisterMessage(CreateServiceAccountRequest)

UpdateServiceAccountRequest = _reflection.GeneratedProtocolMessageType('UpdateServiceAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESERVICEACCOUNTREQUEST,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdateServiceAccountRequest)
  })
_sym_db.RegisterMessage(UpdateServiceAccountRequest)

ServiceAccountRequest = _reflection.GeneratedProtocolMessageType('ServiceAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEACCOUNTREQUEST,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ServiceAccountRequest)
  })
_sym_db.RegisterMessage(ServiceAccountRequest)

GetServiceAccountRequest = _reflection.GeneratedProtocolMessageType('GetServiceAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSERVICEACCOUNTREQUEST,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetServiceAccountRequest)
  })
_sym_db.RegisterMessage(GetServiceAccountRequest)

ServiceAccountQuery = _reflection.GeneratedProtocolMessageType('ServiceAccountQuery', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEACCOUNTQUERY,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ServiceAccountQuery)
  })
_sym_db.RegisterMessage(ServiceAccountQuery)

ServiceAccountInfo = _reflection.GeneratedProtocolMessageType('ServiceAccountInfo', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEACCOUNTINFO,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ServiceAccountInfo)
  })
_sym_db.RegisterMessage(ServiceAccountInfo)

ServiceAccountsInfo = _reflection.GeneratedProtocolMessageType('ServiceAccountsInfo', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEACCOUNTSINFO,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ServiceAccountsInfo)
  })
_sym_db.RegisterMessage(ServiceAccountsInfo)

ServiceAccountStatQuery = _reflection.GeneratedProtocolMessageType('ServiceAccountStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _SERVICEACCOUNTSTATQUERY,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ServiceAccountStatQuery)
  })
_sym_db.RegisterMessage(ServiceAccountStatQuery)

RegionConfigQuery = _reflection.GeneratedProtocolMessageType('RegionConfigQuery', (_message.Message,), {
  'DESCRIPTOR' : _REGIONCONFIGQUERY,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RegionConfigQuery)
  })
_sym_db.RegisterMessage(RegionConfigQuery)

RegionConfigData = _reflection.GeneratedProtocolMessageType('RegionConfigData', (_message.Message,), {
  'DESCRIPTOR' : _REGIONCONFIGDATA,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RegionConfigData)
  })
_sym_db.RegisterMessage(RegionConfigData)

RegionsConfigInfo = _reflection.GeneratedProtocolMessageType('RegionsConfigInfo', (_message.Message,), {
  'DESCRIPTOR' : _REGIONSCONFIGINFO,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RegionsConfigInfo)
  })
_sym_db.RegisterMessage(RegionsConfigInfo)

RegionConfigInfo = _reflection.GeneratedProtocolMessageType('RegionConfigInfo', (_message.Message,), {
  'DESCRIPTOR' : _REGIONCONFIGINFO,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RegionConfigInfo)
  })
_sym_db.RegisterMessage(RegionConfigInfo)

UpdateRegionConfigRequest = _reflection.GeneratedProtocolMessageType('UpdateRegionConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEREGIONCONFIGREQUEST,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdateRegionConfigRequest)
  })
_sym_db.RegisterMessage(UpdateRegionConfigRequest)

GetRegionConfigRequest = _reflection.GeneratedProtocolMessageType('GetRegionConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREGIONCONFIGREQUEST,
  '__module__' : 'spaceone.api.identity.v1.service_account_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetRegionConfigRequest)
  })
_sym_db.RegisterMessage(GetRegionConfigRequest)

_SERVICEACCOUNT = DESCRIPTOR.services_by_name['ServiceAccount']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SERVICEACCOUNT.methods_by_name['create']._options = None
  _SERVICEACCOUNT.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\037\"\035/identity/v1/service-accounts'
  _SERVICEACCOUNT.methods_by_name['update']._options = None
  _SERVICEACCOUNT.methods_by_name['update']._serialized_options = b'\202\323\344\223\0023\0321/identity/v1/service-account/{service_account_id}'
  _SERVICEACCOUNT.methods_by_name['update_region_config']._options = None
  _SERVICEACCOUNT.methods_by_name['update_region_config']._serialized_options = b'\202\323\344\223\0023\0321/identity/v1/service-account/update-region-config'
  _SERVICEACCOUNT.methods_by_name['delete']._options = None
  _SERVICEACCOUNT.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0023*1/identity/v1/service-account/{service_account_id}'
  _SERVICEACCOUNT.methods_by_name['get_region_config']._options = None
  _SERVICEACCOUNT.methods_by_name['get_region_config']._serialized_options = b'\202\323\344\223\0020\032./identity/v1/service-account/get-region-config'
  _SERVICEACCOUNT.methods_by_name['get']._options = None
  _SERVICEACCOUNT.methods_by_name['get']._serialized_options = b'\202\323\344\223\0023\0221/identity/v1/service-account/{service_account_id}'
  _SERVICEACCOUNT.methods_by_name['list']._options = None
  _SERVICEACCOUNT.methods_by_name['list']._serialized_options = b'\202\323\344\223\002G\022\035/identity/v1/service-accountsZ&\"$/identity/v1/service-accounts/search'
  _SERVICEACCOUNT.methods_by_name['list_available_region']._options = None
  _SERVICEACCOUNT.methods_by_name['list_available_region']._serialized_options = b'\202\323\344\223\002s\0223/identity/v1/service-accounts/list-available-regionZ<\":/identity/v1/service-accounts/list-available-region/search'
  _SERVICEACCOUNT.methods_by_name['stat']._options = None
  _SERVICEACCOUNT.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002$\"\"/identity/v1/service-accounts/stat'
  _CREATESERVICEACCOUNTREQUEST._serialized_start=240
  _CREATESERVICEACCOUNTREQUEST._serialized_end=484
  _UPDATESERVICEACCOUNTREQUEST._serialized_start=487
  _UPDATESERVICEACCOUNTREQUEST._serialized_end=752
  _SERVICEACCOUNTREQUEST._serialized_start=754
  _SERVICEACCOUNTREQUEST._serialized_end=824
  _GETSERVICEACCOUNTREQUEST._serialized_start=826
  _GETSERVICEACCOUNTREQUEST._serialized_end=913
  _SERVICEACCOUNTQUERY._serialized_start=916
  _SERVICEACCOUNTQUERY._serialized_end=1161
  _SERVICEACCOUNTINFO._serialized_start=1164
  _SERVICEACCOUNTINFO._serialized_end=1503
  _SERVICEACCOUNTSINFO._serialized_start=1505
  _SERVICEACCOUNTSINFO._serialized_end=1610
  _SERVICEACCOUNTSTATQUERY._serialized_start=1612
  _SERVICEACCOUNTSTATQUERY._serialized_end=1710
  _REGIONCONFIGQUERY._serialized_start=1713
  _REGIONCONFIGQUERY._serialized_end=1861
  _REGIONCONFIGDATA._serialized_start=1864
  _REGIONCONFIGDATA._serialized_end=2027
  _REGIONCONFIGDATA_ISAVAILABLE._serialized_start=1983
  _REGIONCONFIGDATA_ISAVAILABLE._serialized_end=2027
  _REGIONSCONFIGINFO._serialized_start=2029
  _REGIONSCONFIGINFO._serialized_end=2130
  _REGIONCONFIGINFO._serialized_start=2133
  _REGIONCONFIGINFO._serialized_end=2323
  _UPDATEREGIONCONFIGREQUEST._serialized_start=2326
  _UPDATEREGIONCONFIGREQUEST._serialized_end=2505
  _GETREGIONCONFIGREQUEST._serialized_start=2507
  _GETREGIONCONFIGREQUEST._serialized_end=2616
  _SERVICEACCOUNT._serialized_start=2619
  _SERVICEACCOUNT._serialized_end=4169
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/statistics/v1/resource.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)spaceone/api/statistics/v1/resource.proto\x12\x1aspaceone.api.statistics.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x8f\x01\n\x12StatAggregateQuery\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x34\n\x05query\x18\x02 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12,\n\x0b\x65xtend_data\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x99\x02\n\x11StatAggregateJoin\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x34\n\x05query\x18\x02 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12,\n\x0b\x65xtend_data\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x44\n\x04type\x18\x04 \x01(\x0e\x32\x36.spaceone.api.statistics.v1.StatAggregateJoin.JoinType\x12\x0c\n\x04keys\x18\x05 \x03(\t\"5\n\x08JoinType\x12\x08\n\x04LEFT\x10\x00\x12\t\n\x05RIGHT\x10\x01\x12\t\n\x05OUTER\x10\x02\x12\t\n\x05INNER\x10\x03\"\x90\x01\n\x13StatAggregateConcat\x12\x15\n\rresource_type\x18\x01 \x01(\t\x12\x34\n\x05query\x18\x02 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12,\n\x0b\x65xtend_data\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"$\n\x07SortKey\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\x08\"a\n\x11StatAggregateSort\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x65sc\x18\x02 \x01(\x08\x12\x31\n\x04keys\x18\x03 \x03(\x0b\x32#.spaceone.api.statistics.v1.SortKey\"H\n\x14StatAggregateFormula\x12\x0e\n\x04\x65val\x18\x01 \x01(\tH\x00\x12\x0f\n\x05query\x18\x02 \x01(\tH\x00\x42\x0f\n\rformula_alias\"<\n\x13StatAggregateFillNA\x12%\n\x04\x64\x61ta\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xad\x03\n\rStatAggregate\x12?\n\x05query\x18\x01 \x01(\x0b\x32..spaceone.api.statistics.v1.StatAggregateQueryH\x00\x12=\n\x04join\x18\x02 \x01(\x0b\x32-.spaceone.api.statistics.v1.StatAggregateJoinH\x00\x12\x41\n\x06\x63oncat\x18\x03 \x01(\x0b\x32/.spaceone.api.statistics.v1.StatAggregateConcatH\x00\x12=\n\x04sort\x18\x04 \x01(\x0b\x32-.spaceone.api.statistics.v1.StatAggregateSortH\x00\x12\x43\n\x07\x66ormula\x18\x05 \x01(\x0b\x32\x30.spaceone.api.statistics.v1.StatAggregateFormulaH\x00\x12\x42\n\x07\x66ill_na\x18\x06 \x01(\x0b\x32/.spaceone.api.statistics.v1.StatAggregateFillNAH\x00\x42\x11\n\x0f\x61ggregate_alias\"(\n\x08StatPage\x12\r\n\x05start\x18\x01 \x01(\r\x12\r\n\x05limit\x18\x02 \x01(\r\"\xb6\x01\n\x13ResourceStatRequest\x12<\n\taggregate\x18\x01 \x03(\x0b\x32).spaceone.api.statistics.v1.StatAggregate\x12\x32\n\x04page\x18\x02 \x01(\x0b\x32$.spaceone.api.statistics.v1.StatPage\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x1a\n\x12\x61llow_delete_state\x18\x04 \x01(\x08\x32\x83\x01\n\x08Resource\x12w\n\x04stat\x12/.spaceone.api.statistics.v1.ResourceStatRequest\x1a\x17.google.protobuf.Struct\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/statistics/v1/resources/statb\x06proto3')



_STATAGGREGATEQUERY = DESCRIPTOR.message_types_by_name['StatAggregateQuery']
_STATAGGREGATEJOIN = DESCRIPTOR.message_types_by_name['StatAggregateJoin']
_STATAGGREGATECONCAT = DESCRIPTOR.message_types_by_name['StatAggregateConcat']
_SORTKEY = DESCRIPTOR.message_types_by_name['SortKey']
_STATAGGREGATESORT = DESCRIPTOR.message_types_by_name['StatAggregateSort']
_STATAGGREGATEFORMULA = DESCRIPTOR.message_types_by_name['StatAggregateFormula']
_STATAGGREGATEFILLNA = DESCRIPTOR.message_types_by_name['StatAggregateFillNA']
_STATAGGREGATE = DESCRIPTOR.message_types_by_name['StatAggregate']
_STATPAGE = DESCRIPTOR.message_types_by_name['StatPage']
_RESOURCESTATREQUEST = DESCRIPTOR.message_types_by_name['ResourceStatRequest']
_STATAGGREGATEJOIN_JOINTYPE = _STATAGGREGATEJOIN.enum_types_by_name['JoinType']
StatAggregateQuery = _reflection.GeneratedProtocolMessageType('StatAggregateQuery', (_message.Message,), {
  'DESCRIPTOR' : _STATAGGREGATEQUERY,
  '__module__' : 'spaceone.api.statistics.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StatAggregateQuery)
  })
_sym_db.RegisterMessage(StatAggregateQuery)

StatAggregateJoin = _reflection.GeneratedProtocolMessageType('StatAggregateJoin', (_message.Message,), {
  'DESCRIPTOR' : _STATAGGREGATEJOIN,
  '__module__' : 'spaceone.api.statistics.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StatAggregateJoin)
  })
_sym_db.RegisterMessage(StatAggregateJoin)

StatAggregateConcat = _reflection.GeneratedProtocolMessageType('StatAggregateConcat', (_message.Message,), {
  'DESCRIPTOR' : _STATAGGREGATECONCAT,
  '__module__' : 'spaceone.api.statistics.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StatAggregateConcat)
  })
_sym_db.RegisterMessage(StatAggregateConcat)

SortKey = _reflection.GeneratedProtocolMessageType('SortKey', (_message.Message,), {
  'DESCRIPTOR' : _SORTKEY,
  '__module__' : 'spaceone.api.statistics.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.SortKey)
  })
_sym_db.RegisterMessage(SortKey)

StatAggregateSort = _reflection.GeneratedProtocolMessageType('StatAggregateSort', (_message.Message,), {
  'DESCRIPTOR' : _STATAGGREGATESORT,
  '__module__' : 'spaceone.api.statistics.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StatAggregateSort)
  })
_sym_db.RegisterMessage(StatAggregateSort)

StatAggregateFormula = _reflection.GeneratedProtocolMessageType('StatAggregateFormula', (_message.Message,), {
  'DESCRIPTOR' : _STATAGGREGATEFORMULA,
  '__module__' : 'spaceone.api.statistics.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StatAggregateFormula)
  })
_sym_db.RegisterMessage(StatAggregateFormula)

StatAggregateFillNA = _reflection.GeneratedProtocolMessageType('StatAggregateFillNA', (_message.Message,), {
  'DESCRIPTOR' : _STATAGGREGATEFILLNA,
  '__module__' : 'spaceone.api.statistics.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StatAggregateFillNA)
  })
_sym_db.RegisterMessage(StatAggregateFillNA)

StatAggregate = _reflection.GeneratedProtocolMessageType('StatAggregate', (_message.Message,), {
  'DESCRIPTOR' : _STATAGGREGATE,
  '__module__' : 'spaceone.api.statistics.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StatAggregate)
  })
_sym_db.RegisterMessage(StatAggregate)

StatPage = _reflection.GeneratedProtocolMessageType('StatPage', (_message.Message,), {
  'DESCRIPTOR' : _STATPAGE,
  '__module__' : 'spaceone.api.statistics.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StatPage)
  })
_sym_db.RegisterMessage(StatPage)

ResourceStatRequest = _reflection.GeneratedProtocolMessageType('ResourceStatRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCESTATREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.resource_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.ResourceStatRequest)
  })
_sym_db.RegisterMessage(ResourceStatRequest)

_RESOURCE = DESCRIPTOR.services_by_name['Resource']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCE.methods_by_name['stat']._options = None
  _RESOURCE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\037\"\035/statistics/v1/resources/stat'
  _STATAGGREGATEQUERY._serialized_start=168
  _STATAGGREGATEQUERY._serialized_end=311
  _STATAGGREGATEJOIN._serialized_start=314
  _STATAGGREGATEJOIN._serialized_end=595
  _STATAGGREGATEJOIN_JOINTYPE._serialized_start=542
  _STATAGGREGATEJOIN_JOINTYPE._serialized_end=595
  _STATAGGREGATECONCAT._serialized_start=598
  _STATAGGREGATECONCAT._serialized_end=742
  _SORTKEY._serialized_start=744
  _SORTKEY._serialized_end=780
  _STATAGGREGATESORT._serialized_start=782
  _STATAGGREGATESORT._serialized_end=879
  _STATAGGREGATEFORMULA._serialized_start=881
  _STATAGGREGATEFORMULA._serialized_end=953
  _STATAGGREGATEFILLNA._serialized_start=955
  _STATAGGREGATEFILLNA._serialized_end=1015
  _STATAGGREGATE._serialized_start=1018
  _STATAGGREGATE._serialized_end=1447
  _STATPAGE._serialized_start=1449
  _STATPAGE._serialized_end=1489
  _RESOURCESTATREQUEST._serialized_start=1492
  _RESOURCESTATREQUEST._serialized_end=1674
  _RESOURCE._serialized_start=1677
  _RESOURCE._serialized_end=1808
# @@protoc_insertion_point(module_scope)
